
from __future__ import annotations
from datetime import datetime
from enum import Enum
from pyconnectwise.models.base.connectwise_model import ConnectWiseModel
from pydantic import ConfigDict, Field

class AVTemplatePolicy(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    template_policy_id: (str | None) = Field(default=None, alias='TemplatePolicyId')
    name: (str | None) = Field(default=None, alias='Name')
    description: (str | None) = Field(default=None, alias='Description')
    guid: (str | None) = Field(default=None, alias='GUID')

class AVTemplatePolicyData(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    template_policy_id: (str | None) = Field(default=None, alias='TemplatePolicyId')
    plugin_guid: (str | None) = Field(default=None, alias='PluginGUID')
    data: (str | None) = Field(default=None, alias='Data')

class CacheControl(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    cache_id: (str | None) = Field(default=None, alias='CacheId')
    custom_commands: (datetime | None) = Field(default=None, alias='CustomCommands')
    custom_menus: (datetime | None) = Field(default=None, alias='CustomMenus')
    huds: (datetime | None) = Field(default=None, alias='Huds')
    apps: (datetime | None) = Field(default=None, alias='Apps')
    user_folders: (datetime | None) = Field(default=None, alias='UserFolders')
    users: (datetime | None) = Field(default=None, alias='Users')
    schedules: (datetime | None) = Field(default=None, alias='Schedules')
    templates: (datetime | None) = Field(default=None, alias='Templates')
    data_view_folders: (datetime | None) = Field(default=None, alias='DataViewFolders')
    dataviews: (datetime | None) = Field(default=None, alias='Dataviews')
    report_folders: (datetime | None) = Field(default=None, alias='ReportFolders')
    reports: (datetime | None) = Field(default=None, alias='Reports')
    links: (datetime | None) = Field(default=None, alias='Links')
    script_folders: (datetime | None) = Field(default=None, alias='ScriptFolders')
    scripts: (datetime | None) = Field(default=None, alias='Scripts')
    sensor_checks: (datetime | None) = Field(default=None, alias='SensorChecks')
    audit_actions: (datetime | None) = Field(default=None, alias='AuditActions')
    remote_commands: (datetime | None) = Field(default=None, alias='RemoteCommands')
    contacts: (datetime | None) = Field(default=None, alias='Contacts')
    time_category: (datetime | None) = Field(default=None, alias='TimeCategory')
    ticket_data: (datetime | None) = Field(default=None, alias='TicketData')
    ticket_category: (datetime | None) = Field(default=None, alias='TicketCategory')
    functions: (datetime | None) = Field(default=None, alias='Functions')
    redirectors: (datetime | None) = Field(default=None, alias='Redirectors')
    virus_scanners: (datetime | None) = Field(default=None, alias='VirusScanners')
    control_center_config: (datetime | None) = Field(default=None, alias='ControlCenterConfig')
    properties: (datetime | None) = Field(default=None, alias='Properties')
    config: (datetime | None) = Field(default=None, alias='Config')
    regions: (datetime | None) = Field(default=None, alias='Regions')
    config_outlook: (datetime | None) = Field(default=None, alias='ConfigOutlook')
    computers: (datetime | None) = Field(default=None, alias='Computers')
    locations: (datetime | None) = Field(default=None, alias='Locations')
    clients: (datetime | None) = Field(default=None, alias='Clients')
    groups: (datetime | None) = Field(default=None, alias='Groups')
    agents: (datetime | None) = Field(default=None, alias='Agents')
    permissions: (datetime | None) = Field(default=None, alias='Permissions')
    write_config_control: (datetime | None) = Field(default=None, alias='WriteConfigControl')
    alert_templates: (datetime | None) = Field(default=None, alias='AlertTemplates')
    role_definitions: (datetime | None) = Field(default=None, alias='RoleDefinitions')

class ComputerChassis(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    manufacturer: (str | None) = Field(default=None, alias='Manufacturer')
    product_name: (str | None) = Field(default=None, alias='ProductName')
    version: (str | None) = Field(default=None, alias='Version')
    serial_number: (str | None) = Field(default=None, alias='SerialNumber')
    uuid: (str | None) = Field(default=None, alias='UUID')
    sku_number: (str | None) = Field(default=None, alias='SkuNumber')
    family: (str | None) = Field(default=None, alias='Family')
    chassis_type: (str | None) = Field(default=None, alias='ChassisType')
    chassis_lock: (bool | None) = Field(default=None, alias='ChassisLock')
    asset_tag: (str | None) = Field(default=None, alias='AssetTag')
    height_units: (int | None) = Field(default=None, alias='HeightUnits')
    system_boot_state: (int | None) = Field(default=None, alias='SystemBootState')
    power_supply_boot_state: (int | None) = Field(default=None, alias='PowerSupplyBootState')
    thermal_boot_state: (int | None) = Field(default=None, alias='ThermalBootState')
    main_board_product: (str | None) = Field(default=None, alias='MainBoardProduct')
    main_board_serial_number: (str | None) = Field(default=None, alias='MainBoardSerialNumber')
    main_board_version: (str | None) = Field(default=None, alias='MainBoardVersion')
    main_board_manufacturer: (str | None) = Field(default=None, alias='MainBoardManufacturer')
    last_update: (datetime | None) = Field(default=None, alias='LastUpdate')

class Router(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    manufacturer_name: (str | None) = Field(default=None, alias='ManufacturerName')
    model: (str | None) = Field(default=None, alias='Model')
    version: (str | None) = Field(default=None, alias='Version')
    port_type: (str | None) = Field(default=None, alias='PortType')
    username: (str | None) = Field(default=None, alias='Username')
    password: (str | None) = Field(default=None, alias='Password')
    guid: (str | None) = Field(default=None, alias='Guid')

class EventLogInventoryMode(Enum):
    INVENTORY_ONLY_USES_SCHEDULE = 'InventoryOnlyUsesSchedule'
    IMMEDIATELY_SEND_ERRORS = 'ImmediatelySendErrors'
    IMMEDIATELY_SEND_ERRORS_AND_WARNINGS = 'ImmediatelySendErrorsAndWarnings'
    IMMEDIATELY_SEND_ALL_BUT_SECURITY = 'ImmediatelySendAllButSecurity'
    IMMEDIATELY_SEND_ALL = 'ImmediatelySendAll'

class WindowsUpdate(Enum):
    DO_NOTHING = 'DoNothing'
    ENABLE_WINDOWS_UPDATE_DEFAULTS = 'EnableWindowsUpdateDefaults'
    SET_TO_DOWNLOAD_ONLY = 'SetToDownloadOnly'
    DISABLE_WINDOWS_UPDATE = 'DisableWindowsUpdate'
    LABTECH_MODE_LABTECH_MODE_UI_ACCESS_DISABLED = 'LabtechModeLabtechModeUIAccessDisabled'

class AgentRebootMode(Enum):
    NOW = 'Now'
    ASK = 'Ask'
    ASK_THEN_ALLOW = 'AskThenAllow'
    ASK_THEN_DENY = 'AskThenDeny'
    DENY = 'Deny'

class RemoteAccessMode(Enum):
    SILENT = 'Silent'
    ASK = 'Ask'
    ASK_THEN_ALLOW = 'AskThenAllow'
    ASK_THEN_DENY = 'AskThenDeny'
    DENY = 'Deny'

class FileExplorerAccessMode(Enum):
    NOW = 'Now'
    ASK = 'Ask'
    ASK_THEN_ALLOW = 'AskThenAllow'
    ASK_THEN_DENY = 'AskThenDeny'
    DENY = 'Deny'

class RegistryEditorAccessMode(Enum):
    NOW = 'Now'
    ASK = 'Ask'
    ASK_THEN_ALLOW = 'AskThenAllow'
    ASK_THEN_DENY = 'AskThenDeny'
    DENY = 'Deny'

class ScreenCaptureAccessMode(Enum):
    NOW = 'Now'
    ASK = 'Ask'
    ASK_THEN_ALLOW = 'AskThenAllow'
    ASK_THEN_DENY = 'AskThenDeny'
    DENY = 'Deny'

class ContactWebPermissions(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    tickets: (bool | None) = Field(default=None, alias='Tickets')
    remote_access: (bool | None) = Field(default=None, alias='RemoteAccess')
    install_agent: (bool | None) = Field(default=None, alias='InstallAgent')
    reboot: (bool | None) = Field(default=None, alias='Reboot')
    shutdown: (bool | None) = Field(default=None, alias='Shutdown')
    wake_on_lan: (bool | None) = Field(default=None, alias='WakeOnLAN')
    multi_factor_required: (bool | None) = Field(default=None, alias='MultiFactorRequired')

class DayId(Enum):
    EVERYDAY = 'Everyday'
    SUNDAY = 'Sunday'
    MONDAY = 'Monday'
    TUESDAY = 'Tuesday'
    WEDNESDAY = 'Wednesday'
    THURSDAY = 'Thursday'
    FRIDAY = 'Friday'
    SATURDAY = 'Saturday'

class Schedule(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    day_id: (DayId | None) = Field(default=None, alias='DayId')
    day_name: (str | None) = Field(default=None, alias='DayName')
    repeat_every_hour: (int | None) = Field(default=None, alias='RepeatEveryHour')
    date: (datetime | None) = Field(default=None, alias='Date')

class ComputerMenu(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    menu_id: (str | None) = Field(default=None, alias='MenuID')
    name: (str | None) = Field(default=None, alias='Name')
    description: (str | None) = Field(default=None, alias='Description')
    text: (str | None) = Field(default=None, alias='Text')
    image_url: (str | None) = Field(default=None, alias='ImageURL')
    root_only: (int | None) = Field(default=None, alias='RootOnly')
    action: (str | None) = Field(default=None, alias='Action')
    msg_title: (str | None) = Field(default=None, alias='MsgTitle')
    msg_body: (str | None) = Field(default=None, alias='MsgBody')
    msg_height: (int | None) = Field(default=None, alias='MsgHeight')
    msg_width: (int | None) = Field(default=None, alias='MsgWidth')
    ur_lor_exe: (str | None) = Field(default=None, alias='URLorEXE')
    script_id: (int | None) = Field(default=None, alias='ScriptID')
    parameters: (str | None) = Field(default=None, alias='Parameters')

class TemplateProperty(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    template_id: (str | None) = Field(default=None, alias='TemplateID')
    property_name: (str | None) = Field(default=None, alias='PropertyName')
    property_value: (str | None) = Field(default=None, alias='PropertyValue')
    property_description: (str | None) = Field(default=None, alias='PropertyDescription')

class GroupPartial(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='ID')
    parent_id: (int | None) = Field(default=None, alias='ParentId')
    name: (str | None) = Field(default=None, alias='Name')

class SearchType(Enum):
    ADVANCED_COMPUTERS = 'AdvancedComputers'
    ADVANCED_NET_DEVICES = 'AdvancedNetDevices'
    ADVANCED_CONTACTS = 'AdvancedContacts'
    ADVANCED_MOBILE_DEVICES = 'AdvancedMobileDevices'

class MaintenanceWindow(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')

class LoggedInUser(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    logged_in_user_name: (str | None) = Field(default=None, alias='LoggedInUserName')
    console_id: (int | None) = Field(default=None, alias='ConsoleId')

class VirusScannerDef(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class CommentPriority(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class SearchFolder(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ComputerPermissions(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    edit_config: (bool | None) = Field(default=None, alias='EditConfig')
    edit_info: (bool | None) = Field(default=None, alias='EditInfo')
    send_commands: (bool | None) = Field(default=None, alias='SendCommands')
    allow_remote_control: (bool | None) = Field(default=None, alias='AllowRemoteControl')
    allow_redir: (bool | None) = Field(default=None, alias='AllowRedir')
    allow_file_explorer: (bool | None) = Field(default=None, alias='AllowFileExplorer')
    allow_registry_edit: (bool | None) = Field(default=None, alias='AllowRegistryEdit')
    command_prompt: (bool | None) = Field(default=None, alias='CommandPrompt')
    sniff_network: (bool | None) = Field(default=None, alias='SniffNetwork')
    install: (bool | None) = Field(default=None, alias='Install')
    history: (bool | None) = Field(default=None, alias='History')
    view_commands: (bool | None) = Field(default=None, alias='ViewCommands')
    monitor_delete: (bool | None) = Field(default=None, alias='MonitorDelete')
    monitor_add: (bool | None) = Field(default=None, alias='MonitorAdd')
    monitor_edit: (bool | None) = Field(default=None, alias='MonitorEdit')
    clear_alerts: (bool | None) = Field(default=None, alias='ClearAlerts')
    schedule_scripts: (bool | None) = Field(default=None, alias='ScheduleScripts')
    delete_schedule_scripts: (bool | None) = Field(default=None, alias='DeleteScheduleScripts')

class NetworkDeviceType(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class AlertAction(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    comment: (str | None) = Field(default=None, alias='Comment')

class ExternalSystemCredentials(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    credentials_id: (int | None) = Field(default=None, alias='CredentialsId')
    client_id: (int | None) = Field(default=None, alias='ClientId')
    title: (str | None) = Field(default=None, alias='Title')
    expiration_date: (datetime | None) = Field(default=None, alias='ExpirationDate')
    is_active: (bool | None) = Field(default=None, alias='IsActive')

class TicketStatus(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class TicketPriority(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class TicketCategory(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    parent_category_id: (int | None) = Field(default=None, alias='ParentCategoryId')
    keywords: (str | None) = Field(default=None, alias='Keywords')
    description: (str | None) = Field(default=None, alias='Description')
    image: (str | None) = Field(default=None, alias='Image')
    is_visible_in_list: (bool | None) = Field(default=None, alias='IsVisibleInList')

class UserPermissions(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    super_admin: (bool | None) = Field(default=None, alias='SuperAdmin')
    system_config: (bool | None) = Field(default=None, alias='SystemConfig')
    class_config: (bool | None) = Field(default=None, alias='ClassConfig')
    create_tickets: (bool | None) = Field(default=None, alias='CreateTickets')
    shared_links: (bool | None) = Field(default=None, alias='SharedLinks')
    template_read: (bool | None) = Field(default=None, alias='TemplateRead')
    template_edit: (bool | None) = Field(default=None, alias='TemplateEdit')
    template_delete: (bool | None) = Field(default=None, alias='TemplateDelete')
    client_read: (bool | None) = Field(default=None, alias='ClientRead')
    client_edit: (bool | None) = Field(default=None, alias='ClientEdit')
    client_delete: (bool | None) = Field(default=None, alias='ClientDelete')
    report_read: (bool | None) = Field(default=None, alias='ReportRead')
    report_edit: (bool | None) = Field(default=None, alias='ReportEdit')
    report_delete: (bool | None) = Field(default=None, alias='ReportDelete')
    contact_read: (bool | None) = Field(default=None, alias='ContactRead')
    contact_edit: (bool | None) = Field(default=None, alias='ContactEdit')
    contact_delete: (bool | None) = Field(default=None, alias='ContactDelete')
    user_read: (bool | None) = Field(default=None, alias='UserRead')
    user_edit: (bool | None) = Field(default=None, alias='UserEdit')
    user_delete: (bool | None) = Field(default=None, alias='UserDelete')
    tool_read: (bool | None) = Field(default=None, alias='ToolRead')
    tool_edit: (bool | None) = Field(default=None, alias='ToolEdit')
    tool_delete: (bool | None) = Field(default=None, alias='ToolDelete')
    script_read: (bool | None) = Field(default=None, alias='ScriptRead')
    script_edit: (bool | None) = Field(default=None, alias='ScriptEdit')
    script_delete: (bool | None) = Field(default=None, alias='ScriptDelete')
    manage_groups: (bool | None) = Field(default=None, alias='ManageGroups')
    dash_ticketing: (bool | None) = Field(default=None, alias='DashTicketing')
    dash_time: (bool | None) = Field(default=None, alias='DashTime')
    dash_manage: (bool | None) = Field(default=None, alias='DashManage')
    dash_trending: (bool | None) = Field(default=None, alias='DashTrending')
    dash_overview: (bool | None) = Field(default=None, alias='DashOverview')
    hud_update: (bool | None) = Field(default=None, alias='HUDUpdate')
    hud_show_all: (bool | None) = Field(default=None, alias='HUDShowAll')
    data_view_update: (bool | None) = Field(default=None, alias='DataViewUpdate')
    data_view_delete: (bool | None) = Field(default=None, alias='DataViewDelete')
    data_view_show_all: (bool | None) = Field(default=None, alias='DataViewShowAll')
    users_show_all: (bool | None) = Field(default=None, alias='UsersShowAll')
    user_class_create: (bool | None) = Field(default=None, alias='UserClassCreate')
    user_class_update: (bool | None) = Field(default=None, alias='UserClassUpdate')
    patch_manager_config: (bool | None) = Field(default=None, alias='PatchManagerConfig')
    reports_create: (bool | None) = Field(default=None, alias='ReportsCreate')
    probe_template_execute: (bool | None) = Field(default=None, alias='ProbeTemplateExecute')
    scheduled_scripts_update: (bool | None) = Field(default=None, alias='ScheduledScriptsUpdate')
    clients_show_all: (bool | None) = Field(default=None, alias='ClientsShowAll')
    show_passwords: (bool | None) = Field(default=None, alias='ShowPasswords')
    locations_show_all: (bool | None) = Field(default=None, alias='LocationsShowAll')
    computers_create: (bool | None) = Field(default=None, alias='ComputersCreate')
    computers_update: (bool | None) = Field(default=None, alias='ComputersUpdate')
    computers_delete: (bool | None) = Field(default=None, alias='ComputersDelete')
    computers_show_all: (bool | None) = Field(default=None, alias='ComputersShowAll')
    computers_force_update: (bool | None) = Field(default=None, alias='ComputersForceUpdate')
    network_device_update: (bool | None) = Field(default=None, alias='NetworkDeviceUpdate')
    network_device_delete: (bool | None) = Field(default=None, alias='NetworkDeviceDelete')
    network_device_show_all: (bool | None) = Field(default=None, alias='NetworkDeviceShowAll')
    retired_assets_delete: (bool | None) = Field(default=None, alias='RetiredAssetsDelete')
    groups_create: (bool | None) = Field(default=None, alias='GroupsCreate')
    groups_delete: (bool | None) = Field(default=None, alias='GroupsDelete')
    groups_show_all: (bool | None) = Field(default=None, alias='GroupsShowAll')
    groups_schedule_script: (bool | None) = Field(default=None, alias='GroupsScheduleScript')
    group_monitors_update: (bool | None) = Field(default=None, alias='GroupMonitorsUpdate')
    group_info_update: (bool | None) = Field(default=None, alias='GroupInfoUpdate')
    group_managed_services: (bool | None) = Field(default=None, alias='GroupManagedServices')
    remote_monitors_create: (bool | None) = Field(default=None, alias='RemoteMonitorsCreate')
    remote_monitors_delete: (bool | None) = Field(default=None, alias='RemoteMonitorsDelete')
    internal_monitors_create: (bool | None) = Field(default=None, alias='InternalMonitorsCreate')
    internal_monitors_update: (bool | None) = Field(default=None, alias='InternalMonitorsUpdate')
    internal_monitors_delete: (bool | None) = Field(default=None, alias='InternalMonitorsDelete')
    alerts_update: (bool | None) = Field(default=None, alias='AlertsUpdate')
    alerts_delete_all: (bool | None) = Field(default=None, alias='AlertsDeleteAll')
    tickets_read: (bool | None) = Field(default=None, alias='TicketsRead')
    tickets_update: (bool | None) = Field(default=None, alias='TicketsUpdate')
    tickets_delete: (bool | None) = Field(default=None, alias='TicketsDelete')
    tickets_request: (bool | None) = Field(default=None, alias='TicketsRequest')
    searches_read: (bool | None) = Field(default=None, alias='SearchesRead')
    searches_update: (bool | None) = Field(default=None, alias='SearchesUpdate')
    searches_delete: (bool | None) = Field(default=None, alias='SearchesDelete')
    patch_manager_read: (bool | None) = Field(default=None, alias='PatchManagerRead')
    patch_manager_update: (bool | None) = Field(default=None, alias='PatchManagerUpdate')
    language_pack_editor: (bool | None) = Field(default=None, alias='LanguagePackEditor')
    managed_service_catalog: (bool | None) = Field(default=None, alias='ManagedServiceCatalog')
    navigation_menu_update: (bool | None) = Field(default=None, alias='NavigationMenuUpdate')
    rss_feed_read: (bool | None) = Field(default=None, alias='RSSFeedRead')
    rss_feed_update: (bool | None) = Field(default=None, alias='RSSFeedUpdate')
    links_delete: (bool | None) = Field(default=None, alias='LinksDelete')
    plugin_manager: (bool | None) = Field(default=None, alias='PluginManager')
    solution_center: (bool | None) = Field(default=None, alias='SolutionCenter')
    database_execute: (bool | None) = Field(default=None, alias='DatabaseExecute')
    server_status: (bool | None) = Field(default=None, alias='ServerStatus')
    manage_audits: (bool | None) = Field(default=None, alias='ManageAudits')
    manage_remote_commands: (bool | None) = Field(default=None, alias='ManageRemoteCommands')
    manage_service_logs: (bool | None) = Field(default=None, alias='ManageServiceLogs')
    manage_outdated: (bool | None) = Field(default=None, alias='ManageOutdated')
    manage_offline_computers: (bool | None) = Field(default=None, alias='ManageOfflineComputers')
    manage_schedule_client_scripts: (bool | None) = Field(default=None, alias='ManageScheduleClientScripts')
    dashboard_config: (bool | None) = Field(default=None, alias='DashboardConfig')
    config_application_list: (bool | None) = Field(default=None, alias='ConfigApplicationList')
    config_event_black_list: (bool | None) = Field(default=None, alias='ConfigEventBlackList')
    quick_connect: (bool | None) = Field(default=None, alias='QuickConnect')
    permissions_update: (bool | None) = Field(default=None, alias='PermissionsUpdate')
    user_class_read: (bool | None) = Field(default=None, alias='UserClassRead')
    user_class_delete: (bool | None) = Field(default=None, alias='UserClassDelete')

class UserFolder(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    user_folder_id: (str | None) = Field(default=None, alias='UserFolderId')
    name: (str | None) = Field(default=None, alias='Name')
    is_sso_enabled: (bool | None) = Field(default=None, alias='IsSsoEnabled')

class UserSingleSignOnStatus(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    sso_status_id: (int | None) = Field(default=None, alias='SsoStatusId')
    status_name: (str | None) = Field(default=None, alias='StatusName')

class ComputerMonitorHistory(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    failure_rate: (float | None) = Field(default=None, alias='FailureRate')
    last_success_data: (str | None) = Field(default=None, alias='LastSuccessData')
    last_warning_data: (str | None) = Field(default=None, alias='LastWarningData')
    last_fail_data: (str | None) = Field(default=None, alias='LastFailData')

class Command(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    description: (str | None) = Field(default=None, alias='Description')
    level: (int | None) = Field(default=None, alias='Level')

class ComputerBios(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    vendor: (str | None) = Field(default=None, alias='Vendor')
    version: (str | None) = Field(default=None, alias='Version')
    date: (datetime | None) = Field(default=None, alias='Date')
    size: (int | None) = Field(default=None, alias='Size')
    system_bios_version: (float | None) = Field(default=None, alias='SystemBiosVersion')
    embctl_version: (float | None) = Field(default=None, alias='EMBCTLVersion')
    sm_bios_version: (float | None) = Field(default=None, alias='SmBiosVersion')
    dmi_version: (int | None) = Field(default=None, alias='DmiVersion')
    supports_acpi: (bool | None) = Field(default=None, alias='SupportsAcpi')
    supports_apm: (bool | None) = Field(default=None, alias='SupportsApm')
    supports_agp: (bool | None) = Field(default=None, alias='SupportsAgp')
    supports_pcmcia: (bool | None) = Field(default=None, alias='SupportsPcmcia')
    has_smart_battery: (bool | None) = Field(default=None, alias='HasSmartBattery')
    supports_uefi: (bool | None) = Field(default=None, alias='SupportsUefi')
    supports_legacy_usb: (bool | None) = Field(default=None, alias='SupportsLegacyUsb')
    supports_pci: (bool | None) = Field(default=None, alias='SupportsPci')
    supports_vlvesa: (bool | None) = Field(default=None, alias='SupportsVlvesa')
    supports_escd: (bool | None) = Field(default=None, alias='SupportsEscd')
    supports_net_boot: (bool | None) = Field(default=None, alias='SupportsNetBoot')
    supports_i2_o_boot: (bool | None) = Field(default=None, alias='SupportsI2OBoot')
    is_virtual_machine: (bool | None) = Field(default=None, alias='IsVirtualMachine')
    power_on_reason: (str | None) = Field(default=None, alias='PowerOnReason')
    bios_char: (int | None) = Field(default=None, alias='BiosChar')
    is_portable: (bool | None) = Field(default=None, alias='IsPortable')
    vm_host: (str | None) = Field(default=None, alias='VmHost')
    vm_type: (str | None) = Field(default=None, alias='VmType')
    vm_name: (str | None) = Field(default=None, alias='VmName')
    date_updated: (datetime | None) = Field(default=None, alias='DateUpdated')

class ComputerDrive(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    drive_id: (int | None) = Field(default=None, alias='DriveId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    letter: (str | None) = Field(default=None, alias='Letter')
    size: (int | None) = Field(default=None, alias='Size')
    free_space: (int | None) = Field(default=None, alias='FreeSpace')
    file_system: (str | None) = Field(default=None, alias='FileSystem')
    model: (str | None) = Field(default=None, alias='Model')
    smart_status: (str | None) = Field(default=None, alias='SmartStatus')
    is_missing: (bool | None) = Field(default=None, alias='IsMissing')
    date_last_inventoried: (datetime | None) = Field(default=None, alias='DateLastInventoried')
    volume_name: (str | None) = Field(default=None, alias='VolumeName')
    backup_flag: (int | None) = Field(default=None, alias='BackupFlag')
    is_solid_state: (bool | None) = Field(default=None, alias='IsSolidState')
    is_internal: (bool | None) = Field(default=None, alias='IsInternal')
    maximum_history_days_available: (int | None) = Field(default=None, alias='MaximumHistoryDaysAvailable')

class SmartAttribute(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    description: (str | None) = Field(default=None, alias='Description')

class ComputerEffectivePatchingPolicy(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    approval_policy_count: (int | None) = Field(default=None, alias='ApprovalPolicyCount')
    microsoft_update_policy_name: (str | None) = Field(default=None, alias='MicrosoftUpdatePolicyName')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    reboot_policy_name: (str | None) = Field(default=None, alias='RebootPolicyName')
    third_party_update_policy_name: (str | None) = Field(default=None, alias='ThirdPartyUpdatePolicyName')

class PolicyApprovalSetting(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ComputerOperatingSystem(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    name: (str | None) = Field(default=None, alias='Name')
    major_version: (int | None) = Field(default=None, alias='MajorVersion')
    minor_version: (int | None) = Field(default=None, alias='MinorVersion')
    version: (str | None) = Field(default=None, alias='Version')
    dot_net_version: (str | None) = Field(default=None, alias='DotNetVersion')
    service_pack: (str | None) = Field(default=None, alias='ServicePack')
    service_pack_name: (str | None) = Field(default=None, alias='ServicePackName')
    product_type: (int | None) = Field(default=None, alias='ProductType')
    suite: (int | None) = Field(default=None, alias='Suite')
    product_info: (int | None) = Field(default=None, alias='ProductInfo')
    is_licensed: (bool | None) = Field(default=None, alias='IsLicensed')
    is_tablet: (bool | None) = Field(default=None, alias='IsTablet')
    is_starter: (bool | None) = Field(default=None, alias='IsStarter')
    is_media_center: (bool | None) = Field(default=None, alias='IsMediaCenter')
    base_folder: (str | None) = Field(default=None, alias='BaseFolder')
    system_drive: (str | None) = Field(default=None, alias='SystemDrive')
    has_gui: (bool | None) = Field(default=None, alias='HasGui')
    is64_bit: (bool | None) = Field(default=None, alias='Is64Bit')
    domain: (str | None) = Field(default=None, alias='Domain')
    is_domain_controller: (bool | None) = Field(default=None, alias='IsDomainController')
    is_server: (bool | None) = Field(default=None, alias='IsServer')
    install_date: (datetime | None) = Field(default=None, alias='InstallDate')
    date_updated: (datetime | None) = Field(default=None, alias='DateUpdated')
    release_id: (int | None) = Field(default=None, alias='ReleaseId')
    edition: (str | None) = Field(default=None, alias='Edition')
    branch_readiness_level: (int | None) = Field(default=None, alias='BranchReadinessLevel')

class ComputerPatchingPolicy(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    approval_policy_count: (int | None) = Field(default=None, alias='ApprovalPolicyCount')
    group_id: (int | None) = Field(default=None, alias='GroupId')
    microsoft_update_policy_name: (str | None) = Field(default=None, alias='MicrosoftUpdatePolicyName')
    name: (str | None) = Field(default=None, alias='Name')
    override_id: (int | None) = Field(default=None, alias='OverrideId')
    priority: (int | None) = Field(default=None, alias='Priority')
    reboot_policy_name: (str | None) = Field(default=None, alias='RebootPolicyName')
    third_party_update_policy_name: (str | None) = Field(default=None, alias='ThirdPartyUpdatePolicyName')

class ComputerPrinter(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    name: (str | None) = Field(default=None, alias='Name')
    port_name: (str | None) = Field(default=None, alias='PortName')
    resolution: (str | None) = Field(default=None, alias='Resolution')
    paper_types: (list[str] | None) = Field(default=None, alias='PaperTypes')
    features: (list[str] | None) = Field(default=None, alias='Features')

class Status(Enum):
    RUNNING = 'Running'
    COMPLETED = 'Completed'

class ComputerRunningScript(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    script_id: (int | None) = Field(default=None, alias='ScriptId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    name: (str | None) = Field(default=None, alias='Name')
    status: (Status | None) = Field(default=None, alias='Status')
    start_date: (datetime | None) = Field(default=None, alias='StartDate')

class ComputerDevice(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    pnp_device_id: (str | None) = Field(default=None, alias='PnpDeviceId')
    device_name: (str | None) = Field(default=None, alias='DeviceName')
    device_type: (str | None) = Field(default=None, alias='DeviceType')
    driver_version: (str | None) = Field(default=None, alias='DriverVersion')
    driver_date: (datetime | None) = Field(default=None, alias='DriverDate')
    driver_name: (str | None) = Field(default=None, alias='DriverName')
    driver_file: (str | None) = Field(default=None, alias='DriverFile')
    manufacturer: (str | None) = Field(default=None, alias='Manufacturer')
    update_date: (datetime | None) = Field(default=None, alias='UpdateDate')

class MaintenanceMode(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerID')
    time_start: (datetime | None) = Field(default=None, alias='TimeStart')
    duration: (int | None) = Field(default=None, alias='Duration')
    mode: (int | None) = Field(default=None, alias='Mode')
    user_id: (int | None) = Field(default=None, alias='UserID')

class MemoryFormFactor(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class MemoryType(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ProcessorSocket(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ProcessorFamily(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ComputerProcessorCache(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    size: (int | None) = Field(default=None, alias='Size')

class ServiceClassification(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class SoftwareClassification(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class VideoCardArchitecture(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class VideoCardMemory(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ComputerScheduledTask(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    command: (str | None) = Field(default=None, alias='Command')
    is_interactive: (bool | None) = Field(default=None, alias='IsInteractive')
    start_time: (str | None) = Field(default=None, alias='StartTime')
    does_repeat: (bool | None) = Field(default=None, alias='DoesRepeat')
    days_of_week: (list[str] | None) = Field(default=None, alias='DaysOfWeek')

class State(Enum):
    FAILURE = 'Failure'
    INFORMATION = 'Information'
    SUCCESS = 'Success'

class ComputerScriptHistory(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    script_id: (int | None) = Field(default=None, alias='ScriptId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    name: (str | None) = Field(default=None, alias='Name')
    user: (str | None) = Field(default=None, alias='User')
    status: (Status | None) = Field(default=None, alias='Status')
    state: (State | None) = Field(default=None, alias='State')
    history_date: (datetime | None) = Field(default=None, alias='HistoryDate')
    diagnostic_message: (str | None) = Field(default=None, alias='DiagnosticMessage')

class SensorDeviceType(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    device_type: (int | None) = Field(default=None, alias='DeviceType')
    name: (str | None) = Field(default=None, alias='Name')
    indicator: (str | None) = Field(default=None, alias='Indicator')

class ComputerSystemSlot(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    id: (int | None) = Field(default=None, alias='Id')
    slot_handle: (int | None) = Field(default=None, alias='SlotHandle')
    slot_name: (str | None) = Field(default=None, alias='SlotName')
    slot_type: (str | None) = Field(default=None, alias='SlotType')
    bus_width: (str | None) = Field(default=None, alias='BusWidth')
    in_use: (str | None) = Field(default=None, alias='InUse')
    length: (str | None) = Field(default=None, alias='Length')
    supports3_volts: (bool | None) = Field(default=None, alias='Supports3Volts')
    supports5_volts: (bool | None) = Field(default=None, alias='Supports5Volts')
    is_hot_pluggable: (bool | None) = Field(default=None, alias='IsHotPluggable')
    supports_power_management: (bool | None) = Field(default=None, alias='SupportsPowerManagement')

class PatchComplianceState(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ThirdParyInstallAction(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ThirdPartyPolicyApproval(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class ComputerUps(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    ups_id: (int | None) = Field(default=None, alias='UpsId')
    ups_name: (str | None) = Field(default=None, alias='UpsName')
    charge_remaining: (int | None) = Field(default=None, alias='ChargeRemaining')
    remaining_run_time: (int | None) = Field(default=None, alias='RemainingRunTime')

class DataViewFolder(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class DataView(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    folder_id: (int | None) = Field(default=None, alias='FolderId')

class Document(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    client_id: (int | None) = Field(default=None, alias='ClientId')
    name: (str | None) = Field(default=None, alias='Name')
    size: (int | None) = Field(default=None, alias='Size')
    data: (str | None) = Field(default=None, alias='Data')
    last_user: (str | None) = Field(default=None, alias='LastUser')
    last_edit_date: (datetime | None) = Field(default=None, alias='LastEditDate')

class EventLogType(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class FeatureFlag(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    is_enabled: (bool | None) = Field(default=None, alias='IsEnabled')

class GroupComputer(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    group_id: (str | None) = Field(default=None, alias='GroupId')
    computer_id: (str | None) = Field(default=None, alias='ComputerId')

class GroupContact(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    group_id: (str | None) = Field(default=None, alias='GroupId')
    contact_id: (str | None) = Field(default=None, alias='ContactId')

class GroupNetworkDevice(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    group_id: (str | None) = Field(default=None, alias='GroupId')
    device_id: (str | None) = Field(default=None, alias='DeviceId')

class LicensedProduct(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    cd_key: (str | None) = Field(default=None, alias='CdKey')
    current_license_usage: (int | None) = Field(default=None, alias='CurrentLicenseUsage')
    data: (str | None) = Field(default=None, alias='Data')
    is_license_active: (bool | None) = Field(default=None, alias='IsLicenseActive')
    license_file: (str | None) = Field(default=None, alias='LicenseFile')
    max_license_usage: (int | None) = Field(default=None, alias='MaxLicenseUsage')
    product_id: (int | None) = Field(default=None, alias='ProductId')
    product_sku: (str | None) = Field(default=None, alias='ProductSku')

class Link(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    url: (str | None) = Field(default=None, alias='URL')
    category: (str | None) = Field(default=None, alias='Category')

class ProductKey(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    client_id: (int | None) = Field(default=None, alias='ClientId')
    product_name: (str | None) = Field(default=None, alias='ProductName')
    serial_number: (str | None) = Field(default=None, alias='SerialNumber')
    license_key: (str | None) = Field(default=None, alias='LicenseKey')
    does_expire: (bool | None) = Field(default=None, alias='DoesExpire')
    expiration_date: (datetime | None) = Field(default=None, alias='ExpirationDate')
    notes: (str | None) = Field(default=None, alias='Notes')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    computer_name: (str | None) = Field(default=None, alias='ComputerName')

class ReportCategory(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    icon: (str | None) = Field(default=None, alias='Icon')
    title_text: (str | None) = Field(default=None, alias='TitleText')

class ScriptFolder(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    parent_id: (str | None) = Field(default=None, alias='ParentId')
    name: (str | None) = Field(default=None, alias='Name')
    guid: (str | None) = Field(default=None, alias='GUID')
    sub_folders: (list[ScriptFolder] | None) = Field(default=None, alias='SubFolders')
    parent_folder: (ScriptFolder | None) = Field(default=None, alias='ParentFolder')

class ScriptMetadata(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    extra_data_fields: (str | None) = Field(default=None, alias='ExtraDataFields')
    parameters: (str | None) = Field(default=None, alias='Parameters')
    globals: (str | None) = Field(default=None, alias='Globals')
    script_version: (int | None) = Field(default=None, alias='ScriptVersion')
    script_guid: (str | None) = Field(default=None, alias='ScriptGuid')

class ScriptStep(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    script_section: (int | None) = Field(default=None, alias='ScriptSection')
    function_id: (int | None) = Field(default=None, alias='FunctionId')
    param1: (str | None) = Field(default=None, alias='Param1')
    param2: (str | None) = Field(default=None, alias='Param2')
    param3: (str | None) = Field(default=None, alias='Param3')
    param4: (str | None) = Field(default=None, alias='Param4')
    param5: (str | None) = Field(default=None, alias='Param5')
    sort: (int | None) = Field(default=None, alias='Sort')
    continue_: (int | None) = Field(default=None, alias='Continue')
    os_limit: (int | None) = Field(default=None, alias='OsLimit')
    indentation: (int | None) = Field(default=None, alias='Indentation')

class PatchActionArgs(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    entity_type: (int | None) = Field(default=None, alias='EntityType')
    entity_id: (int | None) = Field(default=None, alias='EntityId')

class PatchInformation(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    web_server_patch_version: (str | None) = Field(default=None, alias='WebServerPatchVersion')
    db_agent_server_patch_version: (str | None) = Field(default=None, alias='DBAgentServerPatchVersion')
    control_center_patch_version: (str | None) = Field(default=None, alias='ControlCenterPatchVersion')
    remote_agent_patch_version: (str | None) = Field(default=None, alias='RemoteAgentPatchVersion')
    linux_agent_patch_version: (str | None) = Field(default=None, alias='LinuxAgentPatchVersion')
    mac_agent_patch_version: (str | None) = Field(default=None, alias='MacAgentPatchVersion')
    last_patched_date: (datetime | None) = Field(default=None, alias='LastPatchedDate')

class ScheduledScript(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    script_id: (int | None) = Field(default=None, alias='ScriptId')
    client_id: (int | None) = Field(default=None, alias='ClientId')
    location_id: (int | None) = Field(default=None, alias='LocationId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    group_id: (int | None) = Field(default=None, alias='GroupId')
    include_subgroups: (bool | None) = Field(default=None, alias='IncludeSubgroups')
    search_id: (int | None) = Field(default=None, alias='SearchId')
    disabled: (bool | None) = Field(default=None, alias='Disabled')
    effective_start_date: (datetime | None) = Field(default=None, alias='EffectiveStartDate')
    effective_end_date: (datetime | None) = Field(default=None, alias='EffectiveEndDate')
    effective_occurrences: (int | None) = Field(default=None, alias='EffectiveOccurrences')
    distribution_window_type: (int | None) = Field(default=None, alias='DistributionWindowType')
    distribution_window_amount: (int | None) = Field(default=None, alias='DistributionWindowAmount')
    next_run: (datetime | None) = Field(default=None, alias='NextRun')
    next_schedule: (datetime | None) = Field(default=None, alias='NextSchedule')
    schedule_type: (int | None) = Field(default=None, alias='ScheduleType')
    exclude_time_start: (str | None) = Field(default=None, alias='ExcludeTimeStart')
    exclude_time_end: (str | None) = Field(default=None, alias='ExcludeTimeEnd')
    interval: (int | None) = Field(default=None, alias='Interval')
    schedule_week_of_month: (int | None) = Field(default=None, alias='ScheduleWeekOfMonth')
    schedule_day_of_week: (int | None) = Field(default=None, alias='ScheduleDayOfWeek')
    repeat_type: (int | None) = Field(default=None, alias='RepeatType')
    repeat_amount: (int | None) = Field(default=None, alias='RepeatAmount')
    repeat_stop_after: (int | None) = Field(default=None, alias='RepeatStopAfter')
    skip_offline: (bool | None) = Field(default=None, alias='SkipOffline')
    offline_only: (bool | None) = Field(default=None, alias='OfflineOnly')
    wake_offline: (bool | None) = Field(default=None, alias='WakeOffline')
    wake_script: (bool | None) = Field(default=None, alias='WakeScript')
    disable_time_zone: (bool | None) = Field(default=None, alias='DisableTimeZone')
    run_script_on_probe: (bool | None) = Field(default=None, alias='RunScriptOnProbe')
    parameters: (str | None) = Field(default=None, alias='Parameters')
    priority: (int | None) = Field(default=None, alias='Priority')
    time_zone_add: (float | None) = Field(default=None, alias='TimeZoneAdd')
    user: (str | None) = Field(default=None, alias='User')
    last_update: (datetime | None) = Field(default=None, alias='LastUpdate')

class SensorCheckType(Enum):
    SYSTEM_AVERAGES = 'SystemAverages'
    SYSTEM_COUNTS = 'SystemCounts'
    TRENDS = 'Trends'
    PER_DAY_COUNTS = 'PerDayCounts'

class SensorCheck(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    sensor_check_type: (SensorCheckType | None) = Field(default=None, alias='SensorCheckType')

class TemplateAvailableProperty(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    property_id: (str | None) = Field(default=None, alias='PropertyId')
    property_name: (str | None) = Field(default=None, alias='PropertyName')
    property_description: (str | None) = Field(default=None, alias='PropertyDescription')
    property_guid: (str | None) = Field(default=None, alias='PropertyGuid')

class AuditAction(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    level: (int | None) = Field(default=None, alias='Level')
    extension_name: (str | None) = Field(default=None, alias='ExtensionName')

class AuditSource(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')

class UserFavorite(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    user_id: (int | None) = Field(default=None, alias='UserId')
    additional_identifier: (str | None) = Field(default=None, alias='AdditionalIdentifier')
    order: (int | None) = Field(default=None, alias='Order')
    item_guid: (str | None) = Field(default=None, alias='ItemGUID')

class UserSetting(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    user_id: (int | None) = Field(default=None, alias='UserId')
    name: (str | None) = Field(default=None, alias='Name')
    value: (str | None) = Field(default=None, alias='Value')

class RemoteAgentSchedule(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    update_config: (Schedule | None) = Field(default=None, alias='UpdateConfig')
    hardware_inventory: (Schedule | None) = Field(default=None, alias='HardwareInventory')
    system_inventory: (Schedule | None) = Field(default=None, alias='SystemInventory')
    drive_inventory: (Schedule | None) = Field(default=None, alias='DriveInventory')
    process_inventory: (Schedule | None) = Field(default=None, alias='ProcessInventory')
    maleware_inventory: (Schedule | None) = Field(default=None, alias='MalewareInventory')
    software_inventory: (Schedule | None) = Field(default=None, alias='SoftwareInventory')
    event_inventory: (Schedule | None) = Field(default=None, alias='EventInventory')
    printer_inventory: (Schedule | None) = Field(default=None, alias='PrinterInventory')
    network_inventory: (Schedule | None) = Field(default=None, alias='NetworkInventory')
    network_analysis: (Schedule | None) = Field(default=None, alias='NetworkAnalysis')
    hotfix_inventory: (Schedule | None) = Field(default=None, alias='HotfixInventory')
    service_inventory: (Schedule | None) = Field(default=None, alias='ServiceInventory')
    network_probe_inventory: (Schedule | None) = Field(default=None, alias='NetworkProbeInventory')
    last_update: (datetime | None) = Field(default=None, alias='LastUpdate')
    last_user: (str | None) = Field(default=None, alias='LastUser')

class Search(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    search_folder: (SearchFolder | None) = Field(default=None, alias='SearchFolder')
    is_read_only: (bool | None) = Field(default=None, alias='IsReadOnly')
    search_type: (SearchType | None) = Field(default=None, alias='SearchType')

class UserClass(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    permissions: (UserPermissions | None) = Field(default=None, alias='Permissions')

class User(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    user_id: (str | None) = Field(default=None, alias='UserId')
    folder: (UserFolder | None) = Field(default=None, alias='Folder')
    name: (str | None) = Field(default=None, alias='Name')
    email_address: (str | None) = Field(default=None, alias='EmailAddress')
    sso_status: (UserSingleSignOnStatus | None) = Field(default=None, alias='SsoStatus')

class ComputerMonitor(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    monitor_id: (int | None) = Field(default=None, alias='MonitorId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    device_id: (int | None) = Field(default=None, alias='DeviceId')
    name: (str | None) = Field(default=None, alias='Name')
    state: (str | None) = Field(default=None, alias='State')
    last_scanned: (datetime | None) = Field(default=None, alias='LastScanned')
    last_failed: (datetime | None) = Field(default=None, alias='LastFailed')
    last_inventory_date: (datetime | None) = Field(default=None, alias='LastInventoryDate')
    alert_action: (AlertAction | None) = Field(default=None, alias='AlertAction')
    monitor_history: (ComputerMonitorHistory | None) = Field(default=None, alias='MonitorHistory')

class TicketComment(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    body: (str | None) = Field(default=None, alias='Body')
    created_date: (datetime | None) = Field(default=None, alias='CreatedDate')
    from_: (str | None) = Field(default=None, alias='From')
    user: (User | None) = Field(default=None, alias='User')

class CommandExecute(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    command: (Command | None) = Field(default=None, alias='Command')
    status: (str | None) = Field(default=None, alias='Status')
    parameters: (list[str] | None) = Field(default=None, alias='Parameters')
    output: (str | None) = Field(default=None, alias='Output')
    fastalk: (bool | None) = Field(default=None, alias='Fastalk')
    date_last_inventoried: (datetime | None) = Field(default=None, alias='DateLastInventoried')

class SmartData(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    drive_id: (int | None) = Field(default=None, alias='DriveId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    attribute: (SmartAttribute | None) = Field(default=None, alias='Attribute')
    value: (int | None) = Field(default=None, alias='Value')
    worst: (int | None) = Field(default=None, alias='Worst')
    threshold: (int | None) = Field(default=None, alias='Threshold')
    raw_value: (int | None) = Field(default=None, alias='RawValue')

class ComputerMicrosoftUpdateData(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    category: (str | None) = Field(default=None, alias='Category')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    install_date: (datetime | None) = Field(default=None, alias='InstallDate')
    install_state: (str | None) = Field(default=None, alias='InstallState')
    is_compliant: (bool | None) = Field(default=None, alias='IsCompliant')
    is_failed: (bool | None) = Field(default=None, alias='IsFailed')
    is_installed: (bool | None) = Field(default=None, alias='IsInstalled')
    is_non_compliant: (bool | None) = Field(default=None, alias='IsNonCompliant')
    knowledge_base_id: (int | None) = Field(default=None, alias='KnowledgeBaseId')
    microsoft_update_id: (str | None) = Field(default=None, alias='MicrosoftUpdateId')
    policy_approval: (PolicyApprovalSetting | None) = Field(default=None, alias='PolicyApproval')
    release_date: (datetime | None) = Field(default=None, alias='ReleaseDate')
    severity: (str | None) = Field(default=None, alias='Severity')
    title: (str | None) = Field(default=None, alias='Title')
    cvss: (float | None) = Field(default=None, alias='Cvss')

class ComputerMemorySlot(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    slot_handle: (int | None) = Field(default=None, alias='SlotHandle')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    slot_name: (str | None) = Field(default=None, alias='SlotName')
    bank: (str | None) = Field(default=None, alias='Bank')
    form_factor: (MemoryFormFactor | None) = Field(default=None, alias='FormFactor')
    total_width: (int | None) = Field(default=None, alias='TotalWidth')
    data_width: (int | None) = Field(default=None, alias='DataWidth')
    size: (int | None) = Field(default=None, alias='Size')
    type: (MemoryType | None) = Field(default=None, alias='Type')
    speed: (int | None) = Field(default=None, alias='Speed')
    manufacturer: (str | None) = Field(default=None, alias='Manufacturer')
    serial_number: (str | None) = Field(default=None, alias='SerialNumber')
    part_number: (str | None) = Field(default=None, alias='PartNumber')
    asset_tag: (str | None) = Field(default=None, alias='AssetTag')
    update_date: (datetime | None) = Field(default=None, alias='UpdateDate')

class ComputerProcessor(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    processor_handle: (int | None) = Field(default=None, alias='ProcessorHandle')
    socket: (ProcessorSocket | None) = Field(default=None, alias='Socket')
    is_enabled: (bool | None) = Field(default=None, alias='IsEnabled')
    family: (ProcessorFamily | None) = Field(default=None, alias='Family')
    manufacturer: (str | None) = Field(default=None, alias='Manufacturer')
    speed: (int | None) = Field(default=None, alias='Speed')
    cache_list: (list[ComputerProcessorCache] | None) = Field(default=None, alias='CacheList')
    serial_number: (str | None) = Field(default=None, alias='SerialNumber')
    part_number: (str | None) = Field(default=None, alias='PartNumber')
    cores: (int | None) = Field(default=None, alias='Cores')
    threads: (int | None) = Field(default=None, alias='Threads')
    is64_bit: (bool | None) = Field(default=None, alias='Is64Bit')
    dep: (bool | None) = Field(default=None, alias='DEP')
    is_virtualized: (bool | None) = Field(default=None, alias='IsVirtualized')
    has_power_control: (bool | None) = Field(default=None, alias='HasPowerControl')
    has_hardware_thread: (bool | None) = Field(default=None, alias='HasHardwareThread')
    processor_name: (str | None) = Field(default=None, alias='ProcessorName')
    update_date: (datetime | None) = Field(default=None, alias='UpdateDate')

class ComputerService(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_service_id: (int | None) = Field(default=None, alias='ComputerServiceId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    name: (str | None) = Field(default=None, alias='Name')
    description: (str | None) = Field(default=None, alias='Description')
    state: (str | None) = Field(default=None, alias='State')
    startup: (str | None) = Field(default=None, alias='Startup')
    path_name: (str | None) = Field(default=None, alias='PathName')
    service_type: (str | None) = Field(default=None, alias='ServiceType')
    username: (str | None) = Field(default=None, alias='Username')
    date_last_inventoried: (datetime | None) = Field(default=None, alias='DateLastInventoried')
    run_levels: (str | None) = Field(default=None, alias='RunLevels')
    classification: (ServiceClassification | None) = Field(default=None, alias='Classification')

class ComputerSoftware(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    application_id: (int | None) = Field(default=None, alias='ApplicationId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    name: (str | None) = Field(default=None, alias='Name')
    installation_path: (str | None) = Field(default=None, alias='InstallationPath')
    date_installed: (datetime | None) = Field(default=None, alias='DateInstalled')
    size: (int | None) = Field(default=None, alias='Size')
    uninstaller_path: (str | None) = Field(default=None, alias='UninstallerPath')
    version: (str | None) = Field(default=None, alias='Version')
    classification: (SoftwareClassification | None) = Field(default=None, alias='Classification')
    date_last_inventoried: (datetime | None) = Field(default=None, alias='DateLastInventoried')
    client_id: (int | None) = Field(default=None, alias='ClientId')
    computer_name: (str | None) = Field(default=None, alias='ComputerName')

class ComputerVideoCard(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    pnp_device_id: (str | None) = Field(default=None, alias='PnpDeviceId')
    video_processor: (str | None) = Field(default=None, alias='VideoProcessor')
    mode: (str | None) = Field(default=None, alias='Mode')
    memory: (str | None) = Field(default=None, alias='Memory')
    architecture: (VideoCardArchitecture | None) = Field(default=None, alias='Architecture')
    memory_type: (VideoCardMemory | None) = Field(default=None, alias='MemoryType')
    dac_adapter: (str | None) = Field(default=None, alias='DACAdapter')
    bits_per_pixel: (int | None) = Field(default=None, alias='BitsPerPixel')
    update_date: (datetime | None) = Field(default=None, alias='UpdateDate')

class ComputerSensor(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    sensor_id: (int | None) = Field(default=None, alias='SensorId')
    sensor_name: (str | None) = Field(default=None, alias='SensorName')
    device_type: (SensorDeviceType | None) = Field(default=None, alias='DeviceType')
    monitor: (str | None) = Field(default=None, alias='Monitor')
    value: (float | None) = Field(default=None, alias='Value')
    max_value: (float | None) = Field(default=None, alias='MaxValue')

class ComputerThirdPartyPatch(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    approved_version: (str | None) = Field(default=None, alias='ApprovedVersion')
    available_version: (str | None) = Field(default=None, alias='AvailableVersion')
    compliance_state: (PatchComplianceState | None) = Field(default=None, alias='ComplianceState')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    display_title: (str | None) = Field(default=None, alias='DisplayTitle')
    install_action: (ThirdParyInstallAction | None) = Field(default=None, alias='InstallAction')
    install_date: (datetime | None) = Field(default=None, alias='InstallDate')
    install_state: (str | None) = Field(default=None, alias='InstallState')
    installed_version: (str | None) = Field(default=None, alias='InstalledVersion')
    is64_bit: (bool | None) = Field(default=None, alias='Is64Bit')
    is_compliant: (bool | None) = Field(default=None, alias='IsCompliant')
    is_failed: (bool | None) = Field(default=None, alias='IsFailed')
    is_installed: (bool | None) = Field(default=None, alias='IsInstalled')
    is_non_compliant: (bool | None) = Field(default=None, alias='IsNonCompliant')
    manufacturer: (str | None) = Field(default=None, alias='Manufacturer')
    patch_id: (str | None) = Field(default=None, alias='PatchId')
    policy_approval: (ThirdPartyPolicyApproval | None) = Field(default=None, alias='PolicyApproval')
    software_id: (str | None) = Field(default=None, alias='SoftwareId')
    title: (str | None) = Field(default=None, alias='Title')

class EventLog(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    blacklist_id: (int | None) = Field(default=None, alias='BlacklistId')
    computer_id: (int | None) = Field(default=None, alias='ComputerId')
    event_id: (int | None) = Field(default=None, alias='EventId')
    last_date: (datetime | None) = Field(default=None, alias='LastDate')
    log_name: (str | None) = Field(default=None, alias='LogName')
    log_type: (EventLogType | None) = Field(default=None, alias='LogType')
    message: (str | None) = Field(default=None, alias='Message')
    source: (str | None) = Field(default=None, alias='Source')
    time_generated: (datetime | None) = Field(default=None, alias='TimeGenerated')

class ManagedLicense(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    client_id: (int | None) = Field(default=None, alias='ClientId')
    name: (str | None) = Field(default=None, alias='Name')
    search_string: (str | None) = Field(default=None, alias='SearchString')
    license_count: (int | None) = Field(default=None, alias='LicenseCount')
    installed_count: (int | None) = Field(default=None, alias='InstalledCount')
    product_key: (ProductKey | None) = Field(default=None, alias='ProductKey')

class ScriptData(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    script_metadata: (ScriptMetadata | None) = Field(default=None, alias='ScriptMetadata')
    script_steps: (list[ScriptStep] | None) = Field(default=None, alias='ScriptSteps')

class UserAudit(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    user: (User | None) = Field(default=None, alias='User')
    message: (str | None) = Field(default=None, alias='Message')
    date_created: (datetime | None) = Field(default=None, alias='DateCreated')
    external_id: (int | None) = Field(default=None, alias='ExternalId')
    audit_action: (AuditAction | None) = Field(default=None, alias='AuditAction')
    source: (AuditSource | None) = Field(default=None, alias='Source')
    secondary_identifier: (str | None) = Field(default=None, alias='SecondaryIdentifier')

class RemoteAgentTemplate(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    template_guid: (str | None) = Field(default=None, alias='TemplateGUID')
    server_address: (str | None) = Field(default=None, alias='ServerAddress')
    event_log_inventory_mode: (EventLogInventoryMode | None) = Field(default=None, alias='EventLogInventoryMode')
    windows_update: (WindowsUpdate | None) = Field(default=None, alias='WindowsUpdate')
    ssl_accept_expired_certificates: (bool | None) = Field(default=None, alias='SSLAcceptExpiredCertificates')
    ssl_access_untrusted_certificate_authorities: (bool | None) = Field(default=None, alias='SSLAccessUntrustedCertificateAuthorities')
    ssl_accept_mismatched_names: (bool | None) = Field(default=None, alias='SSLAcceptMismatchedNames')
    ssl_accept_revoked_certificates: (bool | None) = Field(default=None, alias='SSLAcceptRevokedCertificates')
    ssl_accept_all: (bool | None) = Field(default=None, alias='SSLAcceptAll')
    default_language_pack: (str | None) = Field(default=None, alias='DefaultLanguagePack')
    heartbeat_enabled: (bool | None) = Field(default=None, alias='HeartbeatEnabled')
    heartbeat_frequency: (int | None) = Field(default=None, alias='HeartbeatFrequency')
    remote_agent_log_debug: (bool | None) = Field(default=None, alias='RemoteAgentLogDebug')
    schedule: (RemoteAgentSchedule | None) = Field(default=None, alias='Schedule')
    agent_update_window: (Schedule | None) = Field(default=None, alias='AgentUpdateWindow')
    temp_directory: (str | None) = Field(default=None, alias='TempDirectory')
    cache_directory: (str | None) = Field(default=None, alias='CacheDirectory')
    cache_username: (str | None) = Field(default=None, alias='CacheUsername')
    cache_password: (str | None) = Field(default=None, alias='CachePassword')
    cache_patch: (bool | None) = Field(default=None, alias='CachePatch')
    cache_software: (bool | None) = Field(default=None, alias='CacheSoftware')
    cache_update: (bool | None) = Field(default=None, alias='CacheUpdate')
    tray_title: (str | None) = Field(default=None, alias='TrayTitle')
    remote_agent_name: (str | None) = Field(default=None, alias='RemoteAgentName')
    show_tray: (bool | None) = Field(default=None, alias='ShowTray')
    tray_disable_powered_by: (bool | None) = Field(default=None, alias='TrayDisablePoweredBy')
    tray_icon: (str | None) = Field(default=None, alias='TrayIcon')
    agent_reboot_mode: (AgentRebootMode | None) = Field(default=None, alias='AgentRebootMode')
    remote_access_mode: (RemoteAccessMode | None) = Field(default=None, alias='RemoteAccessMode')
    file_explorer_access_mode: (FileExplorerAccessMode | None) = Field(default=None, alias='FileExplorerAccessMode')
    registry_editor_access_mode: (RegistryEditorAccessMode | None) = Field(default=None, alias='RegistryEditorAccessMode')
    screen_capture_access_mode: (ScreenCaptureAccessMode | None) = Field(default=None, alias='ScreenCaptureAccessMode')
    disallow_user_close_tray: (bool | None) = Field(default=None, alias='DisallowUserCloseTray')
    allow_user_disable_remote_access: (bool | None) = Field(default=None, alias='AllowUserDisableRemoteAccess')
    tray_help_url: (str | None) = Field(default=None, alias='TrayHelpURL')
    tray_custom_menu_title: (str | None) = Field(default=None, alias='TrayCustomMenuTitle')
    tray_custom_menu_url: (str | None) = Field(default=None, alias='TrayCustomMenuURL')
    tray_show_custom_menu: (bool | None) = Field(default=None, alias='TrayShowCustomMenu')
    tray_show_help: (bool | None) = Field(default=None, alias='TrayShowHelp')
    tray_menus: (list[ComputerMenu] | None) = Field(default=None, alias='TrayMenus')
    tray_reboot_log_off_notification_text: (str | None) = Field(default=None, alias='TrayRebootLogOffNotificationText')
    tray_shutdown_notification_text: (str | None) = Field(default=None, alias='TrayShutdownNotificationText')
    tray_remote_access_notification_text: (str | None) = Field(default=None, alias='TrayRemoteAccessNotificationText')
    tray_file_explorer_access_notification_text: (str | None) = Field(default=None, alias='TrayFileExplorerAccessNotificationText')
    tray_registry_editor_access_notification_text: (str | None) = Field(default=None, alias='TrayRegistryEditorAccessNotificationText')
    tray_screen_capture_access_notification_text: (str | None) = Field(default=None, alias='TrayScreenCaptureAccessNotificationText')
    service_ticket_title: (str | None) = Field(default=None, alias='ServiceTicketTitle')
    tray_ticket_from_label_text: (str | None) = Field(default=None, alias='TrayTicketFromLabelText')
    tray_ticket_subject_label_text: (str | None) = Field(default=None, alias='TrayTicketSubjectLabelText')
    tray_show_service_ticket_menu: (bool | None) = Field(default=None, alias='TrayShowServiceTicketMenu')
    tray_show_messages_and_tickets: (bool | None) = Field(default=None, alias='TrayShowMessagesAndTickets')
    tray_ticket_verify_email: (bool | None) = Field(default=None, alias='TrayTicketVerifyEmail')
    support_url: (str | None) = Field(default=None, alias='SupportURL')
    rss_feed_address1: (str | None) = Field(default=None, alias='RSSFeedAddress1')
    rss_feed_address2: (str | None) = Field(default=None, alias='RSSFeedAddress2')
    rss_feed_address3: (str | None) = Field(default=None, alias='RSSFeedAddress3')
    rss_feed_address4: (str | None) = Field(default=None, alias='RSSFeedAddress4')
    enable_rss: (bool | None) = Field(default=None, alias='EnableRSS')
    tray_chat_notification_text: (str | None) = Field(default=None, alias='TrayChatNotificationText')
    tray_chat_notification_title: (str | None) = Field(default=None, alias='TrayChatNotificationTitle')
    tray_interrupt_user_with_chat: (bool | None) = Field(default=None, alias='TrayInterruptUserWithChat')
    proxy_server_url: (str | None) = Field(default=None, alias='ProxyServerURL')
    proxy_server_user: (str | None) = Field(default=None, alias='ProxyServerUser')
    proxy_server_password: (str | None) = Field(default=None, alias='ProxyServerPassword')
    tray_notification_title: (str | None) = Field(default=None, alias='TrayNotificationTitle')
    tray_new_message_notification_text: (str | None) = Field(default=None, alias='TrayNewMessageNotificationText')
    tray_new_rss_feed_notification_text: (str | None) = Field(default=None, alias='TrayNewRSSFeedNotificationText')
    tray_remote_access_notification_title: (str | None) = Field(default=None, alias='TrayRemoteAccessNotificationTitle')
    tray_system_message_notification_title: (str | None) = Field(default=None, alias='TraySystemMessageNotificationTitle')
    backup_server_url: (str | None) = Field(default=None, alias='BackupServerURL')
    backup_server_user: (str | None) = Field(default=None, alias='BackupServerUser')
    backup_server_password: (str | None) = Field(default=None, alias='BackupServerPassword')
    network_access_storage_path: (str | None) = Field(default=None, alias='NetworkAccessStoragePath')
    template_properties: (list[TemplateProperty] | None) = Field(default=None, alias='TemplateProperties')
    antivirus_template: (AVTemplatePolicy | None) = Field(default=None, alias='AntivirusTemplate')

class UserClassComputerPermissions(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    user_class: (UserClass | None) = Field(default=None, alias='UserClass')
    permissions: (ComputerPermissions | None) = Field(default=None, alias='Permissions')

class Script(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    folder: (ScriptFolder | None) = Field(default=None, alias='Folder')
    name: (str | None) = Field(default=None, alias='Name')
    comments: (str | None) = Field(default=None, alias='Comments')
    is_computer_script: (bool | None) = Field(default=None, alias='IsComputerScript')
    is_location_script: (bool | None) = Field(default=None, alias='IsLocationScript')
    is_maintenance_script: (bool | None) = Field(default=None, alias='IsMaintenanceScript')
    is_function_script: (bool | None) = Field(default=None, alias='IsFunctionScript')
    is_offline: (bool | None) = Field(default=None, alias='IsOffline')
    ignore_for_mobile_devices: (bool | None) = Field(default=None, alias='IgnoreForMobileDevices')
    is_public_sharable: (bool | None) = Field(default=None, alias='IsPublicSharable')
    is_user_response: (bool | None) = Field(default=None, alias='IsUserResponse')
    is_system_script: (bool | None) = Field(default=None, alias='IsSystemScript')
    is_mobile_device_script: (bool | None) = Field(default=None, alias='IsMobileDeviceScript')
    is_network_device_script: (bool | None) = Field(default=None, alias='IsNetworkDeviceScript')
    is_contact_script: (bool | None) = Field(default=None, alias='IsContactScript')
    version: (int | None) = Field(default=None, alias='Version')
    guid: (str | None) = Field(default=None, alias='GUID')
    parameters: (list[str] | None) = Field(default=None, alias='Parameters')
    edit_permission: (list[int] | None) = Field(default=None, alias='EditPermission')
    permission: (list[int] | None) = Field(default=None, alias='Permission')
    automation_time: (int | None) = Field(default=None, alias='AutomationTime')
    update_date: (datetime | None) = Field(default=None, alias='UpdateDate')
    updated_by: (str | None) = Field(default=None, alias='UpdatedBy')
    full_folder_path: (str | None) = Field(default=None, alias='FullFolderPath')
    script_data: (ScriptData | None) = Field(default=None, alias='ScriptData')

class Client(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    name: (str | None) = Field(default=None, alias='Name')
    company: (str | None) = Field(default=None, alias='Company')
    first_name: (str | None) = Field(default=None, alias='FirstName')
    last_name: (str | None) = Field(default=None, alias='LastName')
    address1: (str | None) = Field(default=None, alias='Address1')
    address2: (str | None) = Field(default=None, alias='Address2')
    city: (str | None) = Field(default=None, alias='City')
    state: (str | None) = Field(default=None, alias='State')
    zip_code: (str | None) = Field(default=None, alias='ZipCode')
    phone_number: (str | None) = Field(default=None, alias='PhoneNumber')
    fax_number: (str | None) = Field(default=None, alias='FaxNumber')
    comment: (str | None) = Field(default=None, alias='Comment')
    country: (str | None) = Field(default=None, alias='Country')
    external_id: (str | None) = Field(default=None, alias='ExternalId')
    uses_in_house_support_staff: (bool | None) = Field(default=None, alias='UsesInHouseSupportStaff')
    new_ticket_notification_email: (str | None) = Field(default=None, alias='NewTicketNotificationEmail')
    is_hidden_from_all_inclusive_group: (bool | None) = Field(default=None, alias='IsHiddenFromAllInclusiveGroup')
    locations: (list[Location] | None) = Field(default=None, alias='Locations')

class Location(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (int | None) = Field(default=None, alias='Id')
    client: (Client | None) = Field(default=None, alias='Client')
    name: (str | None) = Field(default=None, alias='Name')
    address1: (str | None) = Field(default=None, alias='Address1')
    address2: (str | None) = Field(default=None, alias='Address2')
    city: (str | None) = Field(default=None, alias='City')
    state: (str | None) = Field(default=None, alias='State')
    zip_code: (str | None) = Field(default=None, alias='ZipCode')
    country: (str | None) = Field(default=None, alias='Country')
    phone_number: (str | None) = Field(default=None, alias='PhoneNumber')
    fax_number: (str | None) = Field(default=None, alias='FaxNumber')
    contact: (Contact | None) = Field(default=None, alias='Contact')
    comments: (str | None) = Field(default=None, alias='Comments')
    router_port: (int | None) = Field(default=None, alias='RouterPort')
    script_drive: (str | None) = Field(default=None, alias='ScriptDrive')
    script_username: (str | None) = Field(default=None, alias='ScriptUsername')
    script_password: (str | None) = Field(default=None, alias='ScriptPassword')
    script_router_address: (str | None) = Field(default=None, alias='ScriptRouterAddress')
    script_extra1: (str | None) = Field(default=None, alias='ScriptExtra1')
    script_extra2: (str | None) = Field(default=None, alias='ScriptExtra2')
    probe_id: (int | None) = Field(default=None, alias='ProbeId')
    external_id: (int | None) = Field(default=None, alias='ExternalId')
    router: (Router | None) = Field(default=None, alias='Router')
    deployment_template: (RemoteAgentTemplate | None) = Field(default=None, alias='DeploymentTemplate')
    maintenance_window: (TemporaryApiContracts.MaintenanceWindowDefinition | None) = Field(default=None, alias='MaintenanceWindow')
    default_deployment_group: (Group | None) = Field(default=None, alias='DefaultDeploymentGroup')
    default_deployment_login: (TemporaryApiContracts.DeploymentLogin | None) = Field(default=None, alias='DefaultDeploymentLogin')

class Contact(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    location: (Location | None) = Field(default=None, alias='Location')
    client: (Client | None) = Field(default=None, alias='Client')
    first_name: (str | None) = Field(default=None, alias='FirstName')
    last_name: (str | None) = Field(default=None, alias='LastName')
    address1: (str | None) = Field(default=None, alias='Address1')
    address2: (str | None) = Field(default=None, alias='Address2')
    city: (str | None) = Field(default=None, alias='City')
    state: (str | None) = Field(default=None, alias='State')
    zip_code: (str | None) = Field(default=None, alias='ZipCode')
    phone_number: (str | None) = Field(default=None, alias='PhoneNumber')
    mobile_number: (str | None) = Field(default=None, alias='MobileNumber')
    fax_number: (str | None) = Field(default=None, alias='FaxNumber')
    pager_number: (str | None) = Field(default=None, alias='PagerNumber')
    email: (str | None) = Field(default=None, alias='Email')
    external_id: (str | None) = Field(default=None, alias='ExternalId')
    web_permissions: (ContactWebPermissions | None) = Field(default=None, alias='WebPermissions')
    created_date: (datetime | None) = Field(default=None, alias='CreatedDate')
    associated_computers: (list[Computer] | None) = Field(default=None, alias='AssociatedComputers')

class Group(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    parent_id: (str | None) = Field(default=None, alias='ParentId')
    sub_groups: (list[int] | None) = Field(default=None, alias='SubGroups')
    parent_groups: (list[int] | None) = Field(default=None, alias='ParentGroups')
    parents: (list[GroupPartial] | None) = Field(default=None, alias='Parents')
    depth: (int | None) = Field(default=None, alias='Depth')
    name: (str | None) = Field(default=None, alias='Name')
    full_name: (str | None) = Field(default=None, alias='FullName')
    type_id: (int | None) = Field(default=None, alias='TypeId')
    type_name: (str | None) = Field(default=None, alias='TypeName')
    template_priority: (int | None) = Field(default=None, alias='TemplatePriority')
    guid: (str | None) = Field(default=None, alias='GUID')
    computers_auto_join_search: (Search | None) = Field(default=None, alias='ComputersAutoJoinSearch')
    network_devices_auto_join_search: (Search | None) = Field(default=None, alias='NetworkDevicesAutoJoinSearch')
    contacts_auto_join_search: (Search | None) = Field(default=None, alias='ContactsAutoJoinSearch')
    maintenance_window: (MaintenanceWindow | None) = Field(default=None, alias='MaintenanceWindow')
    maintenance_window_last_applied: (datetime | None) = Field(default=None, alias='MaintenanceWindowLastApplied')
    computers_limit_to_search: (bool | None) = Field(default=None, alias='ComputersLimitToSearch')
    network_devices_limit_to_search: (bool | None) = Field(default=None, alias='NetworkDevicesLimitToSearch')
    contacts_limit_to_search: (bool | None) = Field(default=None, alias='ContactsLimitToSearch')
    contacts_join_computers: (bool | None) = Field(default=None, alias='ContactsJoinComputers')
    remote_agent_template: (RemoteAgentTemplate | None) = Field(default=None, alias='RemoteAgentTemplate')
    client_to_sync: (Client | None) = Field(default=None, alias='ClientToSync')
    location_to_sync: (Location | None) = Field(default=None, alias='LocationToSync')
    comments: (str | None) = Field(default=None, alias='Comments')
    computer_permissions: (list[UserClassComputerPermissions] | None) = Field(default=None, alias='ComputerPermissions')
    computers: (list[Computer] | None) = Field(default=None, alias='Computers')
    network_devices: (list[NetworkDevice] | None) = Field(default=None, alias='NetworkDevices')
    contacts: (list[Contact] | None) = Field(default=None, alias='Contacts')

class Computer(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    location: (Location | None) = Field(default=None, alias='Location')
    client: (Client | None) = Field(default=None, alias='Client')
    contact: (Contact | None) = Field(default=None, alias='Contact')
    is_fas_talk: (bool | None) = Field(default=None, alias='IsFasTalk')
    is_master: (bool | None) = Field(default=None, alias='IsMaster')
    is_network_probe: (bool | None) = Field(default=None, alias='IsNetworkProbe')
    is_heartbeat_enabled: (bool | None) = Field(default=None, alias='IsHeartbeatEnabled')
    is_maintenance_mode_enabled: (bool | None) = Field(default=None, alias='IsMaintenanceModeEnabled')
    is_tunnel_supported: (bool | None) = Field(default=None, alias='IsTunnelSupported')
    is_virtual_machine: (bool | None) = Field(default=None, alias='IsVirtualMachine')
    computer_name: (str | None) = Field(default=None, alias='ComputerName')
    operating_system_name: (str | None) = Field(default=None, alias='OperatingSystemName')
    operating_system_version: (str | None) = Field(default=None, alias='OperatingSystemVersion')
    domain_name: (str | None) = Field(default=None, alias='DomainName')
    remote_agent_last_inventory: (datetime | None) = Field(default=None, alias='RemoteAgentLastInventory')
    utc_offset: (int | None) = Field(default=None, alias='UTCOffset')
    open_ports_tcp: (list[int] | None) = Field(default=None, alias='OpenPortsTCP')
    open_ports_udp: (list[int] | None) = Field(default=None, alias='OpenPortsUDP')
    comment: (str | None) = Field(default=None, alias='Comment')
    remote_agent_version: (str | None) = Field(default=None, alias='RemoteAgentVersion')
    remote_agent_last_contact: (datetime | None) = Field(default=None, alias='RemoteAgentLastContact')
    domain_name_servers: (list[str] | None) = Field(default=None, alias='DomainNameServers')
    last_inventory_received: (datetime | None) = Field(default=None, alias='LastInventoryReceived')
    windows_update_date: (datetime | None) = Field(default=None, alias='WindowsUpdateDate')
    antivirus_definition_date: (datetime | None) = Field(default=None, alias='AntivirusDefinitionDate')
    last_heartbeat: (datetime | None) = Field(default=None, alias='LastHeartbeat')
    total_memory: (int | None) = Field(default=None, alias='TotalMemory')
    free_memory: (int | None) = Field(default=None, alias='FreeMemory')
    cpu_usage: (int | None) = Field(default=None, alias='CpuUsage')
    local_ip_address: (str | None) = Field(default=None, alias='LocalIPAddress')
    gateway_ip_address: (str | None) = Field(default=None, alias='GatewayIPAddress')
    system_uptime: (int | None) = Field(default=None, alias='SystemUptime')
    last_startup: (datetime | None) = Field(default=None, alias='LastStartup')
    mac_address: (str | None) = Field(default=None, alias='MACAddress')
    date_added: (datetime | None) = Field(default=None, alias='DateAdded')
    user_idle_time: (int | None) = Field(default=None, alias='UserIdleTime')
    logged_in_users: (list[LoggedInUser] | None) = Field(default=None, alias='LoggedInUsers')
    last_user_name: (str | None) = Field(default=None, alias='LastUserName')
    tickets: (list[Ticket] | None) = Field(default=None, alias='Tickets')
    groups: (list[Group] | None) = Field(default=None, alias='Groups')
    bandwidth: (int | None) = Field(default=None, alias='Bandwidth')
    bandwidth_display: (str | None) = Field(default=None, alias='BandwidthDisplay')
    asset_date: (datetime | None) = Field(default=None, alias='AssetDate')
    asset_tag: (str | None) = Field(default=None, alias='AssetTag')
    warranty_end_date: (datetime | None) = Field(default=None, alias='WarrantyEndDate')
    type: (str | None) = Field(default=None, alias='Type')
    status: (str | None) = Field(default=None, alias='Status')
    master_mode: (str | None) = Field(default=None, alias='MasterMode')
    virus_scanner: (VirusScannerDef | None) = Field(default=None, alias='VirusScanner')
    friendly_name: (str | None) = Field(default=None, alias='FriendlyName')
    is_locked_down: (bool | None) = Field(default=None, alias='IsLockedDown')
    is_system_account: (bool | None) = Field(default=None, alias='IsSystemAccount')
    is_reboot_needed: (bool | None) = Field(default=None, alias='IsRebootNeeded')
    is_virtual_host: (bool | None) = Field(default=None, alias='IsVirtualHost')
    is_heartbeat_running: (bool | None) = Field(default=None, alias='IsHeartbeatRunning')
    has_intel_vpro: (bool | None) = Field(default=None, alias='HasIntelVPRO')
    has_intel_amt: (bool | None) = Field(default=None, alias='HasIntelAMT')
    has_h_pi_lo: (bool | None) = Field(default=None, alias='HasHPiLO')
    temp_files: (str | None) = Field(default=None, alias='TempFiles')
    serial_number: (str | None) = Field(default=None, alias='SerialNumber')
    cpu_score: (float | None) = Field(default=None, alias='CpuScore')
    d3_d_score: (float | None) = Field(default=None, alias='D3DScore')
    disk_score: (float | None) = Field(default=None, alias='DiskScore')
    graphics_score: (float | None) = Field(default=None, alias='GraphicsScore')
    memory_score: (float | None) = Field(default=None, alias='MemoryScore')
    power_profiles: (list[str] | None) = Field(default=None, alias='PowerProfiles')
    current_power_profile: (str | None) = Field(default=None, alias='CurrentPowerProfile')
    bios_manufacturer: (str | None) = Field(default=None, alias='BiosManufacturer')
    bios_flash: (str | None) = Field(default=None, alias='BiosFlash')
    primary_contact_name: (str | None) = Field(default=None, alias='PrimaryContactName')
    comment_priority: (CommentPriority | None) = Field(default=None, alias='CommentPriority')
    irq: (list[int] | None) = Field(default=None, alias='IRQ')
    address: (list[int] | None) = Field(default=None, alias='Address')
    dma: (list[int] | None) = Field(default=None, alias='DMA')
    hardware_ports: (list[str] | None) = Field(default=None, alias='HardwarePorts')
    user_accounts: (list[str] | None) = Field(default=None, alias='UserAccounts')

class NetworkDevice(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    location: (Location | None) = Field(default=None, alias='Location')
    local_ip_address: (str | None) = Field(default=None, alias='LocalIPAddress')
    name: (str | None) = Field(default=None, alias='Name')
    friendly_name: (str | None) = Field(default=None, alias='FriendlyName')
    open_ports_tcp: (list[int] | None) = Field(default=None, alias='OpenPortsTCP')
    device_type: (NetworkDeviceType | None) = Field(default=None, alias='DeviceType')
    detection_template_name: (str | None) = Field(default=None, alias='DetectionTemplateName')
    last_updated: (datetime | None) = Field(default=None, alias='LastUpdated')
    mac_address: (str | None) = Field(default=None, alias='MACAddress')
    status: (str | None) = Field(default=None, alias='Status')
    contact: (Contact | None) = Field(default=None, alias='Contact')
    alert_action: (AlertAction | None) = Field(default=None, alias='AlertAction')
    alert_message: (str | None) = Field(default=None, alias='AlertMessage')
    alert_when_offline: (bool | None) = Field(default=None, alias='AlertWhenOffline')
    date_added: (datetime | None) = Field(default=None, alias='DateAdded')
    snmp_community_get: (str | None) = Field(default=None, alias='SNMPCommunityGet')
    snmp_community_set: (str | None) = Field(default=None, alias='SNMPCommunitySet')
    is_snm_pv1_supported: (bool | None) = Field(default=None, alias='IsSNMPv1Supported')
    is_snm_pv2c_supported: (bool | None) = Field(default=None, alias='IsSNMPv2cSupported')
    is_snm_pv3_supported: (bool | None) = Field(default=None, alias='IsSNMPv3Supported')
    is_low_on_toner: (bool | None) = Field(default=None, alias='IsLowOnToner')
    is_low_on_paper: (bool | None) = Field(default=None, alias='IsLowOnPaper')
    is_high_bandwidth: (bool | None) = Field(default=None, alias='IsHighBandwidth')
    flags_display: (str | None) = Field(default=None, alias='FlagsDisplay')
    manufacturer_name: (str | None) = Field(default=None, alias='ManufacturerName')
    model_name: (str | None) = Field(default=None, alias='ModelName')
    description: (str | None) = Field(default=None, alias='Description')
    uptime: (int | None) = Field(default=None, alias='Uptime')
    uptime_display: (str | None) = Field(default=None, alias='UptimeDisplay')
    data_out: (int | None) = Field(default=None, alias='DataOut')
    data_out_display: (str | None) = Field(default=None, alias='DataOutDisplay')
    data_in: (int | None) = Field(default=None, alias='DataIn')
    data_in_display: (str | None) = Field(default=None, alias='DataInDisplay')
    asset_date: (datetime | None) = Field(default=None, alias='AssetDate')
    last_contact: (datetime | None) = Field(default=None, alias='LastContact')
    nas_percent: (str | None) = Field(default=None, alias='NasPercent')
    groups: (list[Group] | None) = Field(default=None, alias='Groups')
    client: (Client | None) = Field(default=None, alias='Client')
    is_synced_to_manage: (bool | None) = Field(default=None, alias='IsSyncedToManage')
    snmp_tree: (list[int] | None) = Field(default=None, alias='SnmpTree')
    external_system_credentials: (ExternalSystemCredentials | None) = Field(default=None, alias='ExternalSystemCredentials')
    interface_count: (int | None) = Field(default=None, alias='InterfaceCount')
    probe_id: (int | None) = Field(default=None, alias='ProbeId')
    probe_name: (str | None) = Field(default=None, alias='ProbeName')
    agent_deployment_readiness_check: (TemporaryApiContracts.AgentDeploymentReadinessCheck | None) = Field(default=None, alias='AgentDeploymentReadinessCheck')

class Ticket(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    ticket_id: (int | None) = Field(default=None, alias='TicketId')
    client: (Client | None) = Field(default=None, alias='Client')
    computer: (Computer | None) = Field(default=None, alias='Computer')
    status: (TicketStatus | None) = Field(default=None, alias='Status')
    subject: (str | None) = Field(default=None, alias='Subject')
    priority: (TicketPriority | None) = Field(default=None, alias='Priority')
    user: (User | None) = Field(default=None, alias='User')
    due_date: (datetime | None) = Field(default=None, alias='DueDate')
    start_date: (datetime | None) = Field(default=None, alias='StartDate')
    contact_date: (datetime | None) = Field(default=None, alias='ContactDate')
    update_date: (datetime | None) = Field(default=None, alias='UpdateDate')
    from_: (str | None) = Field(default=None, alias='From')
    cc: (str | None) = Field(default=None, alias='CC')
    support_level: (int | None) = Field(default=None, alias='SupportLevel')
    category: (TicketCategory | None) = Field(default=None, alias='Category')
    category_id: (int | None) = Field(default=None, alias='CategoryId')
    category_name: (str | None) = Field(default=None, alias='CategoryName')
    location: (Location | None) = Field(default=None, alias='Location')
    external_id: (int | None) = Field(default=None, alias='ExternalId')
    monitor_id: (int | None) = Field(default=None, alias='MonitorId')
    guid: (str | None) = Field(default=None, alias='Guid')
    agent: (ComputerMonitor | None) = Field(default=None, alias='Agent')
    network_device: (NetworkDevice | None) = Field(default=None, alias='NetworkDevice')
    comments: (list[TicketComment] | None) = Field(default=None, alias='Comments')

class RetiredAsset(ConnectWiseModel):
    model_config = ConfigDict(populate_by_name=True)
    id: (str | None) = Field(default=None, alias='Id')
    client: (Client | None) = Field(default=None, alias='Client')
    location: (Location | None) = Field(default=None, alias='Location')
    computer_name: (str | None) = Field(default=None, alias='ComputerName')
    operating_system_name: (str | None) = Field(default=None, alias='OperatingSystemName')
    operating_system_version: (str | None) = Field(default=None, alias='OperatingSystemVersion')
    comment: (str | None) = Field(default=None, alias='Comment')
    local_ip_address: (str | None) = Field(default=None, alias='LocalIPAddress')
    gateway_ip_address: (str | None) = Field(default=None, alias='GatewayIPAddress')
    asset_tag: (str | None) = Field(default=None, alias='AssetTag')
    asset_date: (datetime | None) = Field(default=None, alias='AssetDate')
    retired_date: (datetime | None) = Field(default=None, alias='RetiredDate')
    retire_comment: (str | None) = Field(default=None, alias='RetireComment')
    computer_id: (str | None) = Field(default=None, alias='ComputerId')
from . import TemporaryApiContracts
